@@ -1,6 +1,8 @@
 package rtype
 
 import (
+	"fmt"
+
 	"github.com/StackExchange/dnscontrol/v4/models"
 	"github.com/StackExchange/dnscontrol/v4/pkg/domaintags"
 	"github.com/StackExchange/dnscontrol/v4/pkg/rtypecontrol"
@@ -17,6 +19,7 @@ type RP struct {
 	dns.RP
 }
 
+// Name returns the DNS record type as a string.
 func (handle *RP) Name() string {
 	return "RP"
 }
@@ -24,7 +27,10 @@ func (handle *RP) Name() string {
 // FromArgs fills in the RecordConfig from []any, which is typically from a parsed config file.
 func (handle *RP) FromArgs(dcn *domaintags.DomainNameVarieties, rec *models.RecordConfig, args []any) error {
 	if err := rtypecontrol.PaveArgs(args[1:], "ss"); err != nil {
-		return err
+		return fmt.Errorf("ERROR: (%s) [RP(%q, %v)]: %w",
+			rec.FilePos,
+			rec.Name, rtypecontrol.StringifyQuoted(args[1:]),
+			err)
 	}
 	fields := &RP{
 		dns.RP{
@@ -46,6 +52,7 @@ func (handle *RP) FromStruct(dcn *domaintags.DomainNameVarieties, rec *models.Re
 	return nil
 }
 
+// CopyToLegacyFields populates the legacy fields of the RecordConfig using the fields in .F.
 func (handle *RP) CopyToLegacyFields(rec *models.RecordConfig) {
 	rp := rec.F.(*RP)
 	_ = rec.SetTarget(rp.Mbox + " " + rp.Txt)
